<?php
/**
 * Architect Engineer functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Architect Engineer
 */

include get_theme_file_path( 'vendor/wptrt/autoload/src/Architect_Engineer_Loader.php' );

$Architect_Engineer_Loader = new \WPTRT\Autoload\Architect_Engineer_Loader();

$Architect_Engineer_Loader->architect_engineer_add( 'WPTRT\\Customize\\Section', get_theme_file_path( 'vendor/wptrt/customize-section-button/src' ) );

$Architect_Engineer_Loader->architect_engineer_register();

if ( ! function_exists( 'architect_engineer_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function architect_engineer_setup() {

		add_theme_support( 'woocommerce' );
		add_theme_support( "responsive-embeds" );
		add_theme_support( "align-wide" );
		add_theme_support( "wp-block-styles" );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

        add_image_size('architect-engineer-featured-header-image', 2000, 660, true);

        // This theme uses wp_nav_menu() in one location.
        register_nav_menus( array(
            'primary' => esc_html__( 'Primary','architect-engineer' ),
	        'footer'=> esc_html__( 'Footer Menu','architect-engineer' ),
        ) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'architect_engineer_custom_background_args', array(
			'default-color' => 'f7ebe5',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 50,
			'width'       => 50,
			'flex-width'  => true,
		) );

		add_editor_style( array( '/editor-style.css' ) );
	}
endif;
add_action( 'after_setup_theme', 'architect_engineer_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function architect_engineer_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'architect_engineer_content_width', 1170 );
}
add_action( 'after_setup_theme', 'architect_engineer_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function architect_engineer_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'architect-engineer' ),
		'id'            => 'sidebar',
		'description'   => esc_html__( 'Add widgets here.', 'architect-engineer' ),
        'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h5 class="widget-title">',
		'after_title'   => '</h5>',
	) );
}
add_action( 'widgets_init', 'architect_engineer_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function architect_engineer_scripts() {

	require_once get_theme_file_path( 'inc/wptt-webfont-loader.php' );

	wp_enqueue_style(
		'josefin',
		wptt_get_webfont_url( 'https://fonts.googleapis.com/css2?family=Josefin+Sans:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;1,100;1,200;1,300;1,400;1,500;1,600;1,700&display=swap' ),
		array(),
		'1.0'
	);

	wp_enqueue_style(
		'lato',
		wptt_get_webfont_url( 'https://fonts.googleapis.com/css2?family=Lato:ital,wght@0,100;0,300;0,400;0,700;0,900;1,100;1,300;1,400;1,700;1,900&display=swap' ),
		array(),
		'1.0'
	);

	wp_enqueue_style( 'architect-engineer-block-editor-style', get_theme_file_uri('/assets/css/block-editor-style.css') );

	// load bootstrap css
    wp_enqueue_style( 'bootstrap-css',get_template_directory_uri() . '/assets/css/bootstrap.css');

    wp_enqueue_style( 'owl.carousel-css',get_template_directory_uri() . '/assets/css/owl.carousel.css');

	wp_enqueue_style( 'architect-engineer-style', get_stylesheet_uri() );

	// fontawesome
	wp_enqueue_style( 'fontawesome-style',get_template_directory_uri().'/assets/css/fontawesome/css/all.css' );

    wp_enqueue_script('architect-engineer-theme-js',get_template_directory_uri() . '/assets/js/theme-script.js', array('jquery'), '', true );

    wp_enqueue_script('owl.carousel-js',get_template_directory_uri() . '/assets/js/owl.carousel.js', array('jquery'), '', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'architect_engineer_scripts' );

/**
 * Enqueue Preloader.
 */
function architect_engineer_preloader() {

  $architect_engineer_theme_color_css = '';
  $architect_engineer_preloader_bg_color = get_theme_mod('architect_engineer_preloader_bg_color');
  $architect_engineer_preloader_dot_1_color = get_theme_mod('architect_engineer_preloader_dot_1_color');
  $architect_engineer_preloader_dot_2_color = get_theme_mod('architect_engineer_preloader_dot_2_color');

	if(get_theme_mod('architect_engineer_preloader_bg_color') == '') {
		$architect_engineer_preloader_bg_color = '#fff';
	}
	if(get_theme_mod('architect_engineer_preloader_dot_1_color') == '') {
		$architect_engineer_preloader_dot_1_color = '#000';
	}
	if(get_theme_mod('architect_engineer_preloader_dot_2_color') == '') {
		$architect_engineer_preloader_dot_2_color = '#d39d65';
	}
	$architect_engineer_theme_color_css = '
	
		.loading{
			background-color: '.esc_attr($architect_engineer_preloader_bg_color).';
		 }
		 @keyframes loading {
		  0%,
		  100% {
		  	transform: translatey(-2.5rem);
		    background-color: '.esc_attr($architect_engineer_preloader_dot_1_color).';
		  }
		  50% {
		  	transform: translatey(2.5rem);
		    background-color: '.esc_attr($architect_engineer_preloader_dot_2_color).';
		  }
		}
	';
    wp_add_inline_style( 'architect-engineer-style',$architect_engineer_theme_color_css );

}
add_action( 'wp_enqueue_scripts', 'architect_engineer_preloader' );

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/*dropdown page sanitization*/
function architect_engineer_sanitize_dropdown_pages( $page_id, $setting ) {
	$page_id = absint( $page_id );
	return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
}

/*checkbox sanitization*/
function architect_engineer_sanitize_checkbox( $input ) {
	// Boolean check
	return ( ( isset( $input ) && true == $input ) ? true : false );
}

function architect_engineer_sanitize_phone_number( $phone ) {
	return preg_replace( '/[^\d+]/', '', $phone );
}

//Float
function architect_engineer_sanitize_float( $input ) {
    return filter_var($input, FILTER_SANITIZE_NUMBER_FLOAT, FILTER_FLAG_ALLOW_FRACTION);
}

//SELECT
function architect_engineer_sanitize_select( $input, $setting ){
    $input = sanitize_key($input);
    $choices = $setting->manager->get_control( $setting->id )->choices;
    return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
}

/**
 * Get CSS
 */

function architect_engineer_getpage_css($hook) {
	if ( 'appearance_page_architect-engineer-info' != $hook ) {
		return;
	}
	wp_enqueue_style( 'architect-engineer-demo-style', get_template_directory_uri() . '/assets/css/demo.css' );
}
add_action( 'admin_enqueue_scripts', 'architect_engineer_getpage_css' );

add_action('after_switch_theme', 'architect_engineer_setup_options');

function architect_engineer_setup_options () {
	wp_redirect( admin_url() . 'themes.php?page=architect-engineer-info.php' );
}

if ( ! defined( 'ARCHITECT_ENGINEER_CONTACT_SUPPORT' ) ) {
define('ARCHITECT_ENGINEER_CONTACT_SUPPORT',__('https://wordpress.org/support/theme/architect-engineer','architect-engineer'));
}
if ( ! defined( 'ARCHITECT_ENGINEER_REVIEW' ) ) {
define('ARCHITECT_ENGINEER_REVIEW',__('https://wordpress.org/support/theme/architect-engineer/reviews/#new-post','architect-engineer'));
}
if ( ! defined( 'ARCHITECT_ENGINEER_LIVE_DEMO' ) ) {
define('ARCHITECT_ENGINEER_LIVE_DEMO',__('https://www.themagnifico.net/demo/architect-engineer/','architect-engineer'));
}
if ( ! defined( 'ARCHITECT_ENGINEER_GET_PREMIUM_PRO' ) ) {
define('ARCHITECT_ENGINEER_GET_PREMIUM_PRO',__('https://www.themagnifico.net/themes/engineer-wordpress-theme/','architect-engineer'));
}
if ( ! defined( 'ARCHITECT_ENGINEER_PRO_DOC' ) ) {
define('ARCHITECT_ENGINEER_PRO_DOC',__('https://www.themagnifico.net/eard/wathiqa/architect-engineer-pro-doc/','architect-engineer'));
}

add_action('admin_menu', 'architect_engineer_themepage');
function architect_engineer_themepage(){
	$theme_info = add_theme_page( __('Theme Options','architect-engineer'), __('Theme Options','architect-engineer'), 'manage_options', 'architect-engineer-info.php', 'architect_engineer_info_page' );
}

function architect_engineer_info_page() {
	$user = wp_get_current_user();
	$architect_engineer_theme = wp_get_theme();
	?>
	<div class="wrap about-wrap architect-engineer-add-css">
		<div>
			<h1>
				<?php esc_html_e('Welcome To ','architect-engineer'); ?><?php echo esc_html( $architect_engineer_theme ); ?>
			</h1>
			<div class="feature-section three-col">
				<div class="col">
					<div class="widgets-holder-wrap">
						<h3><?php esc_html_e("Contact Support", "architect-engineer"); ?></h3>
						<p><?php esc_html_e("Thank you for trying Architect Engineer , feel free to contact us for any support regarding our theme.", "architect-engineer"); ?></p>
						<p><a target="_blank" href="<?php echo esc_url( ARCHITECT_ENGINEER_CONTACT_SUPPORT ); ?>" class="button button-primary get">
							<?php esc_html_e("Contact Support", "architect-engineer"); ?>
						</a></p>
					</div>
				</div>
				<div class="col">
					<div class="widgets-holder-wrap">
						<h3><?php esc_html_e("Checkout Premium", "architect-engineer"); ?></h3>
						<p><?php esc_html_e("Our premium theme comes with extended features like demo content import , responsive layouts etc.", "architect-engineer"); ?></p>
						<p><a target="_blank" href="<?php echo esc_url( ARCHITECT_ENGINEER_GET_PREMIUM_PRO ); ?>" class="button button-primary get">
							<?php esc_html_e("Get Premium", "architect-engineer"); ?>
						</a></p>
					</div>
				</div>
				<div class="col">
					<div class="widgets-holder-wrap">
						<h3><?php esc_html_e("Review", "architect-engineer"); ?></h3>
						<p><?php esc_html_e("If You love Architect Engineer theme then we would appreciate your review about our theme.", "architect-engineer"); ?></p>
						<p><a target="_blank" href="<?php echo esc_url( ARCHITECT_ENGINEER_REVIEW ); ?>" class="button button-primary get">
							<?php esc_html_e("Review", "architect-engineer"); ?>
						</a></p>
					</div>
				</div>
			</div>
		</div>
		<hr>

		<h2><?php esc_html_e("Free Vs Premium","architect-engineer"); ?></h2>
		<div class="architect-engineer-button-container">
			<a target="_blank" href="<?php echo esc_url( ARCHITECT_ENGINEER_PRO_DOC ); ?>" class="button button-primary get">
				<?php esc_html_e("Checkout Documentation", "architect-engineer"); ?>
			</a>
			<a target="_blank" href="<?php echo esc_url( ARCHITECT_ENGINEER_LIVE_DEMO ); ?>" class="button button-primary get">
				<?php esc_html_e("View Theme Demo", "architect-engineer"); ?>
			</a>
		</div>

		<table class="wp-list-table widefat">
			<thead class="table-book">
				<tr>
					<th><strong><?php esc_html_e("Theme Feature", "architect-engineer"); ?></strong></th>
					<th><strong><?php esc_html_e("Basic Version", "architect-engineer"); ?></strong></th>
					<th><strong><?php esc_html_e("Premium Version", "architect-engineer"); ?></strong></th>
				</tr>
			</thead>

			<tbody>
				<tr>
					<td><?php esc_html_e("Header Background Color", "architect-engineer"); ?></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Custom Navigation Logo Or Text", "architect-engineer"); ?></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Hide Logo Text", "architect-engineer"); ?></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>

				<tr>
					<td><?php esc_html_e("Premium Support", "architect-engineer"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Fully SEO Optimized", "architect-engineer"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Recent Posts Widget", "architect-engineer"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>

				<tr>
					<td><?php esc_html_e("Easy Google Fonts", "architect-engineer"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Pagespeed Plugin", "architect-engineer"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Only Show Header Image On Front Page", "architect-engineer"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Show Header Everywhere", "architect-engineer"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Custom Text On Header Image", "architect-engineer"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Full Width (Hide Sidebar)", "architect-engineer"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Only Show Upper Widgets On Front Page", "architect-engineer"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Replace Copyright Text", "architect-engineer"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Upper Widgets Colors", "architect-engineer"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Navigation Color", "architect-engineer"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Post/Page Color", "architect-engineer"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Blog Feed Color", "architect-engineer"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Footer Color", "architect-engineer"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Sidebar Color", "architect-engineer"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Background Color", "architect-engineer"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Importable Demo Content	", "architect-engineer"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
			</tbody>
		</table>
		<div class="architect-engineer-button-container">
			<a target="_blank" href="<?php echo esc_url( ARCHITECT_ENGINEER_GET_PREMIUM_PRO ); ?>" class="button button-primary get">
				<?php esc_html_e("Go Premium", "architect-engineer"); ?>
			</a>
		</div>
	</div>
	<?php
}

// Change number or products per row to 3
add_filter('loop_shop_columns', 'architect_engineer_loop_columns');
if (!function_exists('architect_engineer_loop_columns')) {
	function architect_engineer_loop_columns() {
		$columns = get_theme_mod( 'architect_engineer_products_per_row', 3 );
		return $columns; // 3 products per row
	}
}

//Change number of products that are displayed per page (shop page)
add_filter( 'loop_shop_per_page', 'architect_engineer_shop_per_page', 9 );
function architect_engineer_shop_per_page( $cols ) {
  	$cols = get_theme_mod( 'architect_engineer_product_per_page', 9 );
	return $cols;
}
