<?php
/**
 * Architect Engineer Theme Customizer
 *
 * @link: https://developer.wordpress.org/themes/customize-api/customizer-objects/
 *
 * @package Architect Engineer
 */

use WPTRT\Customize\Section\Architect_Engineer_Button;

add_action( 'customize_register', function( $manager ) {

    $manager->register_section_type( Architect_Engineer_Button::class );

    $manager->add_section(
        new Architect_Engineer_Button( $manager, 'architect_engineer_pro', [
            'title'       => __( 'Architect Engineer Pro', 'architect-engineer' ),
            'priority'    => 0,
            'button_text' => __( 'GET PREMIUM', 'architect-engineer' ),
            'button_url'  => esc_url( 'https://www.themagnifico.net/themes/engineer-wordpress-theme/', 'architect-engineer')
        ] )
    );

} );

// Load the JS and CSS.
add_action( 'customize_controls_enqueue_scripts', function() {

    $version = wp_get_theme()->get( 'Version' );

    wp_enqueue_script(
        'architect-engineer-customize-section-button',
        get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/js/customize-controls.js' ),
        [ 'customize-controls' ],
        $version,
        true
    );

    wp_enqueue_style(
        'architect-engineer-customize-section-button',
        get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/css/customize-controls.css' ),
        [ 'customize-controls' ],
        $version
    );

} );

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function architect_engineer_customize_register($wp_customize){
    $wp_customize->get_setting('blogname')->transport = 'postMessage';
    $wp_customize->get_setting('blogdescription')->transport = 'postMessage';

    $wp_customize->add_setting('architect_engineer_logo_title_text', array(
        'default' => true,
        'sanitize_callback' => 'architect_engineer_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'architect_engineer_logo_title_text',array(
        'label'          => __( 'Enable Disable Title', 'architect-engineer' ),
        'section'        => 'title_tagline',
        'settings'       => 'architect_engineer_logo_title_text',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('architect_engineer_theme_description', array(
        'default' => false,
        'sanitize_callback' => 'architect_engineer_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'architect_engineer_theme_description',array(
        'label'          => __( 'Enable Disable Tagline', 'architect-engineer' ),
        'section'        => 'title_tagline',
        'settings'       => 'architect_engineer_theme_description',
        'type'           => 'checkbox',
    )));

    // General Settings
     $wp_customize->add_section('architect_engineer_general_settings',array(
        'title' => esc_html__('General Settings','architect-engineer'),
        'description' => esc_html__('General settings of our theme.','architect-engineer'),
        'priority'   => 30,
    ));

    $wp_customize->add_setting('architect_engineer_preloader_hide', array(
        'default' => false,
        'sanitize_callback' => 'architect_engineer_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'architect_engineer_preloader_hide',array(
        'label'          => __( 'Show Theme Preloader', 'architect-engineer' ),
        'section'        => 'architect_engineer_general_settings',
        'settings'       => 'architect_engineer_preloader_hide',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting( 'architect_engineer_preloader_bg_color', array(
        'default' => '#fff',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'architect_engineer_preloader_bg_color', array(
        'label' => esc_html__('Preloader Background Color','architect-engineer'),
        'section' => 'architect_engineer_general_settings',
        'settings' => 'architect_engineer_preloader_bg_color'
    )));

    $wp_customize->add_setting( 'architect_engineer_preloader_dot_1_color', array(
        'default' => '#000',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'architect_engineer_preloader_dot_1_color', array(
        'label' => esc_html__('Preloader First Dot Color','architect-engineer'),
        'section' => 'architect_engineer_general_settings',
        'settings' => 'architect_engineer_preloader_dot_1_color'
    )));

    $wp_customize->add_setting( 'architect_engineer_preloader_dot_2_color', array(
        'default' => '#d39d65',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'architect_engineer_preloader_dot_2_color', array(
        'label' => esc_html__('Preloader Second Dot Color','architect-engineer'),
        'section' => 'architect_engineer_general_settings',
        'settings' => 'architect_engineer_preloader_dot_2_color'
    )));

    $wp_customize->add_setting('architect_engineer_scroll_hide', array(
        'default' => false,
        'sanitize_callback' => 'architect_engineer_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'architect_engineer_scroll_hide',array(
        'label'          => __( 'Show Theme Scroll To Top', 'architect-engineer' ),
        'section'        => 'architect_engineer_general_settings',
        'settings'       => 'architect_engineer_scroll_hide',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('architect_engineer_sticky_header', array(
        'default' => false,
        'sanitize_callback' => 'architect_engineer_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'architect_engineer_sticky_header',array(
        'label'          => __( 'Show Sticky Header', 'architect-engineer' ),
        'section'        => 'architect_engineer_general_settings',
        'settings'       => 'architect_engineer_sticky_header',
        'type'           => 'checkbox',
    )));

    // Product Columns
   $wp_customize->add_setting( 'architect_engineer_products_per_row' , array(
       'default'           => '3',
       'transport'         => 'refresh',
       'sanitize_callback' => 'architect_engineer_sanitize_select',
   ) );

   $wp_customize->add_control('architect_engineer_products_per_row', array(
       'label' => __( 'Product per row', 'architect-engineer' ),
       'section'  => 'architect_engineer_general_settings',
       'type'     => 'select',
       'choices'  => array(
           '2' => '2',
           '3' => '3',
           '4' => '4',
       ),
   ) );

   $wp_customize->add_setting('architect_engineer_product_per_page',array(
       'default'   => '9',
       'sanitize_callback' => 'architect_engineer_sanitize_float'
   ));
   $wp_customize->add_control('architect_engineer_product_per_page',array(
       'label' => __('Product per page','architect-engineer'),
       'section'   => 'architect_engineer_general_settings',
       'type'      => 'number'
   ));


    //Header
    $wp_customize->add_section('architect_engineer_header',array(
        'title' => esc_html__('Header Option','architect-engineer')
    ));

    $wp_customize->add_setting('architect_engineer_phone_number',array(
        'default' => '',
        'sanitize_callback' => 'architect_engineer_sanitize_phone_number'
    ));
    $wp_customize->add_control('architect_engineer_phone_number',array(
        'label' => esc_html__('Phone Number','architect-engineer'),
        'section' => 'architect_engineer_header',
        'setting' => 'architect_engineer_phone_number',
        'type'  => 'text'
    ));

    //Slider
    $wp_customize->add_section('architect_engineer_top_slider',array(
        'title' => esc_html__('Slider Option','architect-engineer')
    ));

    for ( $architect_engineer_count = 1; $architect_engineer_count <= 3; $architect_engineer_count++ ) {
        $wp_customize->add_setting( 'architect_engineer_top_slider_page' . $architect_engineer_count, array(
            'default'           => '',
            'sanitize_callback' => 'architect_engineer_sanitize_dropdown_pages'
        ) );
        $wp_customize->add_control( 'architect_engineer_top_slider_page' . $architect_engineer_count, array(
            'label'    => __( 'Select Slide Page', 'architect-engineer' ),
            'section'  => 'architect_engineer_top_slider',
            'type'     => 'dropdown-pages'
        ) );
    }

    $wp_customize->add_setting('architect_engineer_slider_loop', array(
        'default' => 1,
        'sanitize_callback' => 'architect_engineer_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'architect_engineer_slider_loop',array(
        'label'          => __( 'Enable Disable Slider Loop', 'architect-engineer' ),
        'section'        => 'architect_engineer_top_slider',
        'settings'       => 'architect_engineer_slider_loop',
        'type'           => 'checkbox',
    )));

    //Latest Project
    $wp_customize->add_section('architect_engineer_new_project',array(
        'title' => esc_html__('Latest Projects','architect-engineer'),
        'description' => esc_html__('Here you have to select project which will display perticular latest project in the home page.','architect-engineer')
    ));

    $wp_customize->add_setting('architect_engineer_projects_short_title',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('architect_engineer_projects_short_title',array(
        'label' => esc_html__('Short Title','architect-engineer'),
        'section' => 'architect_engineer_new_project',
        'setting' => 'architect_engineer_projects_short_title',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('architect_engineer_projects_title',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('architect_engineer_projects_title',array(
        'label' => esc_html__('Text','architect-engineer'),
        'section' => 'architect_engineer_new_project',
        'setting' => 'architect_engineer_projects_title',
        'type'  => 'text'
    ));

    $categories = get_categories();
    $cat_post = array();
    $cat_post[]= 'select';
    $i = 0;
    foreach($categories as $category){
        if($i==0){
            $default = $category->slug;
            $i++;
        }
        $cat_post[$category->slug] = $category->name;
    }

    $wp_customize->add_setting('architect_engineer_projects_category',array(
        'default'   => 'select',
        'sanitize_callback' => 'architect_engineer_sanitize_select',
    ));
    $wp_customize->add_control('architect_engineer_projects_category',array(
        'type'    => 'select',
        'choices' => $cat_post,
        'label' => __('Select category to display latest projects','architect-engineer'),
        'section' => 'architect_engineer_new_project',
    ));

    // Footer
    $wp_customize->add_section('architect_engineer_site_footer_section', array(
        'title' => esc_html__('Footer', 'architect-engineer'),
    ));

    $wp_customize->add_setting('architect_engineer_footer_text_setting', array(
        'sanitize_callback' => 'sanitize_text_field',
    ));
    $wp_customize->add_control('architect_engineer_footer_text_setting', array(
        'label' => __('Replace the footer text', 'architect-engineer'),
        'section' => 'architect_engineer_site_footer_section',
        'priority' => 1,
        'type' => 'text',
    ));
}
add_action('customize_register', 'architect_engineer_customize_register');

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function architect_engineer_customize_partial_blogname(){
    bloginfo('name');
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function architect_engineer_customize_partial_blogdescription(){
    bloginfo('description');
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function architect_engineer_customize_preview_js(){
    wp_enqueue_script('architect-engineer-customizer', esc_url(get_template_directory_uri()) . '/assets/js/customizer.js', array('customize-preview'), '20151215', true);
}
add_action('customize_preview_init', 'architect_engineer_customize_preview_js');
